notetools.color_note_head_by_numbered_chromatic_pitch_class_color_map
=====================================================================

.. autofunction:: abjad.tools.notetools.color_note_head_by_numbered_chromatic_pitch_class_color_map.color_note_head_by_numbered_chromatic_pitch_class_color_map
